==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/dialog/TransitionDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qvbox.h>
#include <qlabel.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qpushbutton.h> 

#include "TransitionDialog.h"
#include "TransitionData.h"
#include "BrowserTransition.h"
#include "KeyValueTable.h"
#include "UmlWindow.h"
#include "DialogUtil.h"
#include "strutil.h"
#include "UmlDesktop.h"

TransitionDialog::TransitionDialog(TransitionData * r, const QPoint &)
    : MyTabDialog(r->browser_node), rel(r) {
  setCaption("Transition dialog");
  visit = !hasOkButton();  

  BrowserNode * bn = rel->browser_node;
  QGrid * grid;
  
  //
  // general tab
  //
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("name : ", grid);
  edname = new LineEdit(bn->get_name(), grid);
  edname->setReadOnly(visit);
    
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(rel->get_stereotype());
  if (!visit) {
    //edstereotype->insertStringList(rel->get_start()->default_stereotypes(type));
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  //comment->setFont(font);
  
  addTab(grid, "Uml");

  // UML / OCL
  init_tab(uml, rel->uml, "Ocl");

  // CPP
  init_tab(cpp, rel->cpp, "C++");

  // Java
  init_tab(java, rel->java, "Java");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");
  
  UmlDesktop::limitsize_center(this, 0.8, 0.8);
}

void TransitionDialog::init_tab(TransDialog & d, TransDef & td,
				const char * lbl) {
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("trigger : ", grid);
  d.edtrigger = new MultiLineEdit(grid);
  d.edtrigger->setText(td.trigger);
  if (visit)
    d.edtrigger->setReadOnly(TRUE);
  
  new QLabel("guard\nconstraint : ", grid);
  d.edguard = new MultiLineEdit(grid);
  d.edguard->setText(td.guard);
  if (visit)
    d.edguard->setReadOnly(TRUE);
  
  new QLabel("activity\nexpression : ", grid);
  d.edexpr = new MultiLineEdit(grid);
  d.edexpr->setText(td.expr);
  if (visit)
    d.edexpr->setReadOnly(TRUE);
  
  addTab(grid, lbl);
}

void TransitionDialog::edit_description() {
  edit(comment->text(), "transition_description",
       rel, TxtEdit, this, (post_edit) post_edit_description);
}

void TransitionDialog::post_edit_description(TransitionDialog * d, QString s)
{
  d->comment->setText(s);
}

void TransitionDialog::accept() {
  BrowserNode * bn = rel->browser_node;
  QString s;
  
  s = edname->text().stripWhiteSpace();
  if ((s != bn->get_name()) &&
      ((BrowserNode *) bn->parent())->wrong_child_name(s, UmlTransition,
						       bn->allow_spaces(),
						       bn->allow_empty()))
    QMessageBox::critical(0, "Error", s + "\n\nillegal name or already used");
  else {  
    bn->set_name(s);
    rel->set_stereotype(edstereotype->currentText().stripWhiteSpace());
    
    uml.accept(rel->uml);  
    cpp.accept(rel->cpp);  
    java.accept(rel->java);    
    
    bn->set_comment(comment->text());
    UmlWindow::set_commented(bn);
    
    kvtable->update(bn);
    
    bn->modified();
    bn->package_modified();
    rel->modified();
    
    MyTabDialog::accept();
  }
}

void TransDialog::accept(TransDef & td) {
  td.trigger = edtrigger->text();
  td.guard = edguard->text();
  td.expr = edexpr->text();
}

==> bouml_2.7.4.tar.gz: bouml_2.7.4/src/dialog/TransitionDialog.cpp <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#include <qgrid.h> 
#include <qvbox.h>
#include <qlabel.h>
#include <qcombobox.h> 
#include <qmessagebox.h>
#include <qpushbutton.h> 

#include "TransitionDialog.h"
#include "TransitionData.h"
#include "BrowserTransition.h"
#include "KeyValueTable.h"
#include "UmlWindow.h"
#include "DialogUtil.h"
#include "strutil.h"
#include "UmlDesktop.h"
#include "BodyDialog.h"

QSize TransitionDialog::previous_size;

TransitionDialog::TransitionDialog(TransitionData * r, const QPoint &)
    : MyTabDialog(r->browser_node), rel(r) {
  setCaption("Transition dialog");
  visit = !hasOkButton();  

  BrowserNode * bn = rel->browser_node;
  QGrid * grid;
  
  //
  // general tab
  //
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("name : ", grid);
  edname = new LineEdit(bn->get_name(), grid);
  edname->setReadOnly(visit);
    
  new QLabel("stereotype : ", grid);
  edstereotype = new QComboBox(!visit, grid);
  edstereotype->insertItem(rel->get_stereotype());
  if (!visit) {
    //edstereotype->insertStringList(rel->get_start()->default_stereotypes(type));
    edstereotype->setAutoCompletion(TRUE);
  }
  edstereotype->setCurrentItem(0);
  QSizePolicy sp = edstereotype->sizePolicy();
  sp.setHorData(QSizePolicy::Expanding);
  edstereotype->setSizePolicy(sp);
  
  QVBox * vtab = new QVBox(grid);
  new QLabel("description :", vtab);
  if (! visit)
    connect(new SmallPushButton("Editor", vtab), SIGNAL(clicked()),
	    this, SLOT(edit_description()));
  comment = new MultiLineEdit(grid);
  comment->setReadOnly(visit);
  comment->setText(bn->get_comment());
  //comment->setFont(font);
  
  addTab(grid, "Uml");

  // UML / OCL
  init_tab(uml, rel->uml, "Ocl");

  // CPP
  init_tab(cpp, rel->cpp, "C++");

  // Java
  init_tab(java, rel->java, "Java");
  
  // USER : list key - value
  
  grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  kvtable = new KeyValuesTable(bn, grid, visit);
  addTab(grid, "User");

  UmlDesktop::limitsize_center(this, previous_size, 0.8, 0.8);
}

TransitionDialog::~TransitionDialog() {
  previous_size = size();
  
  while (!edits.isEmpty())
    edits.take(0)->close();
}

void TransitionDialog::init_tab(TransDialog & d, TransDef & td,
				const char * lbl) {
  QGrid * grid = new QGrid(2, this);
  grid->setMargin(5);
  grid->setSpacing(5);
  
  new QLabel("trigger : ", grid);
  d.edtrigger = new MultiLineEdit(grid);
  d.edtrigger->setText(td.trigger);
  if (visit)
    d.edtrigger->setReadOnly(TRUE);
  
  new QLabel("guard\nconstraint : ", grid);
  d.edguard = new MultiLineEdit(grid);
  d.edguard->setText(td.guard);
  if (visit)
    d.edguard->setReadOnly(TRUE);
  
  new QLabel("activity\nexpression : ", grid);
  d.edexpr = new MultiLineEdit(grid);
  d.edexpr->setText(td.expr);
  if (visit)
    d.edexpr->setReadOnly(TRUE);
  
  addTab(grid, lbl);
}

void TransitionDialog::edit_description() {
  edit(comment->text(), "transition_description", rel, TxtEdit,
       this, (post_edit) post_edit_description, edits);
}

void TransitionDialog::post_edit_description(TransitionDialog * d, QString s)
{
  d->comment->setText(s);
}

void TransitionDialog::accept() {
  if (!check_edits(edits))
    return;
    
  BrowserNode * bn = rel->browser_node;
  QString s;
  
  s = edname->text().stripWhiteSpace();
  if ((s != bn->get_name()) &&
      ((BrowserNode *) bn->parent())->wrong_child_name(s, UmlTransition,
						       bn->allow_spaces(),
						       bn->allow_empty()))
    QMessageBox::critical(0, "Error", s + "\n\nillegal name or already used");
  else {  
    bn->set_name(s);
    rel->set_stereotype(edstereotype->currentText().stripWhiteSpace());
    
    uml.accept(rel->uml);  
    cpp.accept(rel->cpp);  
    java.accept(rel->java);    
    
    bn->set_comment(comment->text());
    UmlWindow::set_commented(bn);
    
    kvtable->update(bn);
    
    bn->modified();
    bn->package_modified();
    rel->modified();
    
    MyTabDialog::accept();
  }
}

void TransDialog::accept(TransDef & td) {
  td.trigger = edtrigger->text();
  td.guard = edguard->text();
  td.expr = edexpr->text();
}
